@@ -167,43 +167,11 @@ module Gem2Deb
 
     protected # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    def handle_test_failure(test)
-      if ENV['DH_RUBY_IGNORE_TESTS']
-        if ENV['DH_RUBY_IGNORE_TESTS'].split.include?('all')
-          puts "WARNING: Test \"#{test}\" failed, but ignoring all test results."
-          return
-        elsif ENV['DH_RUBY_IGNORE_TESTS'].split.include?(test)
-          puts "WARNING: Test \"#{test}\" failed, but ignoring this test result."
-          return
-        end
-      end
-      if interactive
-        # running interactively
-        continue = nil
-        begin
-          puts
-          print "Test \"#{test}\" failed. Continue building the package? (Y/N) "
-          STDOUT.flush
-          c = STDIN.getc
-          continue = true if c.chr.downcase == 'y'
-          continue = false if c.chr.downcase == 'n'
-        end while continue.nil?
-        if not continue
-          exit(1)
-        end
-      else
-        puts "ERROR: Test \"#{test}\" failed. Exiting."
-        exit(1)
-      end
-    end
-
-    def interactive
-      STDIN.isatty && STDOUT.isatty && STDERR.isatty &&
-        ENV['DEB_BUILD_OPTIONS'] &&
-        ENV['DEB_BUILD_OPTIONS'].split.include?('dh_ruby_interactive')
-    end
-
     def run_tests
+      if skip_all_tests?
+        return
+      end
+
       ruby_versions.each do |rubyver|
         run_tests_for_version(rubyver)
       end
@@ -214,11 +182,31 @@ module Gem2Deb
         return
       end
 
-      begin
-        run_ruby(SUPPORTED_RUBY_VERSIONS[rubyver], TEST_RUNNER)
-      rescue Gem2Deb::CommandFailed
-        handle_test_failure(rubyver)
+      if skip_test?(rubyver)
+        return
       end
+
+      run_ruby(SUPPORTED_RUBY_VERSIONS[rubyver], TEST_RUNNER)
+    end
+
+    def skip_all_tests?
+      if ENV['DH_RUBY_IGNORE_TESTS']
+        if ENV['DH_RUBY_IGNORE_TESTS'].split.include?('all')
+          puts "WARNING: DH_RUBY_IGNORE_TESTS contains \"all\", skipping all tests."
+          return true
+        end
+      end
+      return false
+    end
+
+    def skip_test?(test)
+      if ENV['DH_RUBY_IGNORE_TESTS']
+        if ENV['DH_RUBY_IGNORE_TESTS'].split.include?(test)
+          puts "WARNING: DH_RUBY_IGNORE_TESTS contains \"#{test}\", skipping test for #{test}."
+          return true
+        end
+      end
+      return false
     end
 
     def skip_checks?
